Install
=======

cdshealpix relies on these external dependencies:

- `numpy <https://docs.scipy.org/doc/numpy/>`__
- `astropy <http://docs.astropy.org/en/stable/>`__

To install ``cdshealpix`` type:

.. code-block:: bash

    pip install cdshealpix

If you just want to upgrade ``cdshealpix`` to the latest version:

.. code-block:: bash

    pip install cdshealpix -U


